# FusionFilter

FusionFilter provides a framework for filtering out fusion transcript predictions that are likely to be false positives based on the following criteria:

*  the two partners of a candidate fusion transcript share sequence similarity as determined by a BLAST search.
*  one of the fusion partners is considered promiscuous in that it shows up as having multiple candidate fusion parters.

The Trinity Cancer Transcriptome Analysis Toolkit (CTAT) includes multiple methods for identifying candidate fusion transcripts including [STAR-Fusion](http://star-fusion.github.io), ... others to be listed soon ..., and FusionFilter is used by each as a common framework for filtering out likely false positive predictions.

## Installing FusionFilter

FusionFilter is included as a submodule within each of the Trinity CTAT Fusion resources.  If you would like to install it separately, you can download [FusionFilter from the GitHub Release portal](https://github.com/FusionFilter/FusionFilter/releases).

The data resources required for CTAT fusion transcript discovery in human RNA-Seq cancer samples is readily available as [Hg19_CTAT_resource_lib.tar.gz](https://data.broadinstitute.org/Trinity/CTAT_RESOURCE_LIB/Hg19_CTAT_resource_lib.tar.gz), which includes the human genome Hg19, gencode-v19 annotations, reference cDNA sequences, and coding annotations in gtf format.  Also included are precomputed BLAST+ results from an all-vs-all search of the transcript sequences.

Alignment utilities used by Trinity CTAT include [STAR](https://github.com/alexdobin/STAR), [GMAP](http://research-pub.gene.com/gmap/), and [Bowtie2](http://bowtie-bio.sourceforge.net/bowtie2/index.shtml).  Be sure to have each installed and available for use via your PATH setting.

Then, unpack the data resources and index the resources like so:

     tar xvf Hg19_CTAT_resource_lib.tar.gz

     cd Hg19_CTAT_resource_lib/

     ${FusionFilter_HOME}/prep_genome_lib.pl \
                   --genome_fa ref_genome.fa \
                   --gtf ref_annot.gtf \
                   --cdna_fa ref_cdna.fasta \
                   --blast_pairs blast_pairs.outfmt6.gz


Once the build is complete, you then refer to the above resource directory via the '--genome_lib_dir' parameter of the CTAT utility to be executed.


>If you want to build a resource data set for another genome and corresponding reference annotation set, see our documentation on [Building a Custom FusionFilter Dataset](Building-a-Custom-FusionFilter-Dataset).

